==> flutter_platform_component-3.0.2.tar.gz: example/lib/application/widget/component/list/list_refresh_screen.dart <==
import 'package:flutter_platform_component/flutter_platform_component.dart';
import 'package:example/application/widget/custom/config_section.dart';
import 'package:flutter/widgets.dart';
import 'package:gap/gap.dart';

class ListRefreshScreen extends StatefulWidget {
  const ListRefreshScreen({super.key});

  @override
  State<ListRefreshScreen> createState() => _ListRefreshScreenState();
}

class _ListRefreshScreenState extends State<ListRefreshScreen> {
  final ScrollController _controller = ScrollController();

  @override
  dispose() {
    this._controller.dispose();
    super.dispose();
  }

  Future<void> _onRefresh() async =>
      await Future.delayed(const Duration(seconds: 2));

  @override
  Widget build(BuildContext context) {
    final IFPCSize size = context.fpcSize;

    return FPCScaffold(
      appBar: FPCScreenAppBar(
        context,
        title: "List Refresh",
        onPressedBack: () => Navigator.pop(context),
      ),
      body: FPCListRefresh(
        controller: this._controller,
        onRefresh: this._onRefresh,
        child: FPCPadding(
          child: Column(
            mainAxisSize: MainAxisSize.min,
            children: [
              const ConfigSection(),
              Gap(size.s16 * 2),
              const FPCGreyLightCard(
                child: SizedBox(),
              ),
              Gap(size.s16),
              const FPCGreyLightCard(
                child: SizedBox(),
              ),
              Gap(size.s16),
              const FPCGreyLightCard(
                child: SizedBox(),
              ),
              Gap(size.s16),
              const FPCGreyLightCard(
                child: SizedBox(),
              ),
              //
              Gap(size.s16 * 2),
              const FPCGreyLightCard(
                child: SizedBox(),
              ),
              Gap(size.s16),
              const FPCGreyLightCard(
                child: SizedBox(),
              ),
              Gap(size.s16),
              const FPCGreyLightCard(
                child: SizedBox(),
              ),
              Gap(size.s16),
              const FPCGreyLightCard(
                child: SizedBox(),
              ),
              Gap(size.s16 * 2),
              const FPCGreyLightCard(
                child: SizedBox(),
              ),
              Gap(size.s16),
              const FPCGreyLightCard(
                child: SizedBox(),
              ),
              Gap(size.s16),
              const FPCGreyLightCard(
                child: SizedBox(),
              ),
              Gap(size.s16),
              const FPCGreyLightCard(
                child: SizedBox(),
              ),
              Gap(size.s16 * 2),
              const FPCGreyLightCard(
                child: SizedBox(),
              ),
              Gap(size.s16),
              const FPCGreyLightCard(
                child: SizedBox(),
              ),
              Gap(size.s16),
              const FPCGreyLightCard(
                child: SizedBox(),
              ),
              Gap(size.s16),
              const FPCGreyLightCard(
                child: SizedBox(),
              ),
              Gap(size.s16 * 2),
              const FPCGreyLightCard(
                child: SizedBox(),
              ),
              Gap(size.s16),
              const FPCGreyLightCard(
                child: SizedBox(),
              ),
              Gap(size.s16),
              const FPCGreyLightCard(
                child: SizedBox(),
              ),
              Gap(size.s16),
              const FPCGreyLightCard(
                child: SizedBox(),
              ),
            ],
          ),
        ),
      ),
    );
  }
}

==> flutter_platform_component-4.0.3.tar.gz: example/lib/application/widget/component/list/list_refresh_screen.dart <==
import 'package:flutter_platform_component/flutter_platform_component.dart';
import 'package:example/application/widget/custom/app_bar_config.dart';
import 'package:flutter/widgets.dart';
import 'package:gap/gap.dart';

class ListRefreshScreen extends StatefulWidget {
  const ListRefreshScreen({
    super.key,
  });

  @override
  State<ListRefreshScreen> createState() => _ListRefreshScreenState();
}

class _ListRefreshScreenState extends State<ListRefreshScreen> {
  final ScrollController _controller = ScrollController();

  @override
  dispose() {
    this._controller.dispose();
    super.dispose();
  }

  Future<void> _onRefresh() async =>
      await Future.delayed(const Duration(seconds: 2));

  @override
  Widget build(
    BuildContext context,
  ) {
    final FPCSize size = context.fpcSize;

    return FPCScaffold(
      appBar: AppBarConfig(
        context,
        title: "List Refresh",
        onPressedBack: () => Navigator.pop(context),
      ),
      body: FPCListRefresh(
        controller: this._controller,
        onRefresh: this._onRefresh,
        child: FPCPadding(
          child: Column(
            mainAxisSize: MainAxisSize.min,
            children: [
              const FPCGreyLightCard(
                child: SizedBox(),
              ),
              Gap(size.s16),
              const FPCGreyLightCard(
                child: SizedBox(),
              ),
              Gap(size.s16),
              const FPCGreyLightCard(
                child: SizedBox(),
              ),
              Gap(size.s16),
              const FPCGreyLightCard(
                child: SizedBox(),
              ),
              //
              Gap(size.s16 * 2),
              const FPCGreyLightCard(
                child: SizedBox(),
              ),
              Gap(size.s16),
              const FPCGreyLightCard(
                child: SizedBox(),
              ),
              Gap(size.s16),
              const FPCGreyLightCard(
                child: SizedBox(),
              ),
              Gap(size.s16),
              const FPCGreyLightCard(
                child: SizedBox(),
              ),
              Gap(size.s16 * 2),
              const FPCGreyLightCard(
                child: SizedBox(),
              ),
              Gap(size.s16),
              const FPCGreyLightCard(
                child: SizedBox(),
              ),
              Gap(size.s16),
              const FPCGreyLightCard(
                child: SizedBox(),
              ),
              Gap(size.s16),
              const FPCGreyLightCard(
                child: SizedBox(),
              ),
              Gap(size.s16 * 2),
              const FPCGreyLightCard(
                child: SizedBox(),
              ),
              Gap(size.s16),
              const FPCGreyLightCard(
                child: SizedBox(),
              ),
              Gap(size.s16),
              const FPCGreyLightCard(
                child: SizedBox(),
              ),
              Gap(size.s16),
              const FPCGreyLightCard(
                child: SizedBox(),
              ),
              Gap(size.s16 * 2),
              const FPCGreyLightCard(
                child: SizedBox(),
              ),
              Gap(size.s16),
              const FPCGreyLightCard(
                child: SizedBox(),
              ),
              Gap(size.s16),
              const FPCGreyLightCard(
                child: SizedBox(),
              ),
              Gap(size.s16),
              const FPCGreyLightCard(
                child: SizedBox(),
              ),
            ],
          ),
        ),
      ),
    );
  }
}
